#!/usr/bin/env bash
#
# This script will run a set of lightcurves from a directory specified 
# as a command line argument through a period search
#

# !!!! Assuming all lightcurve files in the input directory are in "MJD MAG" format and named STARID.txt !!!!

# Check input
if [ -z $1 ];then
 echo "Usage:
$0 IC1613MatchedStars"
 exit 1
fi

# Check if all the needed external programs are installed in the system (and accessible in $PATH)
MISSING_PROGRAM=0
LIST_OF_MISSING_PROGRAMS=""
echo " "
echo -e "Starting script \033[01;32m$0\033[00m"
for TESTED_PROGRAM in awk sed bc cat sort head tail grep basename curl wget ;do
 echo -n "Looking for $TESTED_PROGRAM - "
 if ! which $TESTED_PROGRAM &>/dev/null ;then
  MISSING_PROGRAM=1
  LIST_OF_MISSING_PROGRAMS="$LIST_OF_MISSING_PROGRAMS  $TESTED_PROGRAM"
  echo -e "\033[01;31mNOT found\033[00m"
 else
  echo -e "\033[01;32mFound\033[00m"
 fi
done
if [ $MISSING_PROGRAM -eq 1 ] ;then
 echo -e "
ERROR: some programs needed for VaST were not found in the \$PATH!
\033[01;31mPlease install the following programs before compiling VaST:

$LIST_OF_MISSING_PROGRAMS\033[00m
"
 exit 1
else
 echo "All the external programs were found!

"
fi


# Set the input dir with lightcurves
INPUT_DIR_WITH_LIGHTCURVES="$1"
# Set the results dir
RESULTS_DIR="$INPUT_DIR_WITH_LIGHTCURVES"_remote_period_search_results
if [ ! -d $RESULTS_DIR ];then
 # If there is no such directory - create it
 mkdir $RESULTS_DIR
else
 # If there is such a directory from a previous script run - empty it
 # Below is just to make sure "$RESULTS_DIR" != "" so we don't end up doing "rm -rf /" ;)
 if [ -z $RESULTS_DIR ];then
  echo "A big big problem"
  exit 1
 fi
 # Ask the user what to do with the old files
 echo "Found the old results directory $RESULTS_DIR
Should I owerwrite it? (y/n)"
 read ANSWER
 echo "You answered '$ANSWER'"
 if [ "$ANSWER" == "n" ] || [ "$ANSWER" == "N" ] || [ "$ANSWER" == "No" ] || [ "$ANSWER" == "NO" ] || [ "$ANSWER" == "no" ];then
  echo "Ok, than nothing to do..."
  exit 1
 fi
 if [ "$ANSWER" != "y" ] && [ "$ANSWER" != "Y" ] && [ "$ANSWER" != "Yes" ] && [ "$ANSWER" != "YES" ] && [ "$ANSWER" != "yes" ];then
  echo "Sorry, connot understand the answer :(
Please try running '$0 $1' again"
  exit 1
 fi
 echo "Removing the old files from $RESULTS_DIR"
 rm -rf "$RESULTS_DIR"/* 
fi

# Set the current directory name
SCRIPT_WORKDIR="$PWD"
# Set temporary directory name for the HTML and related .png files
TMP_DIR_FOR_HTML_PNG="tmp_dir_html_png/"


# Cycle through each lightcurve
for INPUT_LIGHTCURVE in "$INPUT_DIR_WITH_LIGHTCURVES"/* ;do
 # Just say what we are processing now
 ls $INPUT_LIGHTCURVE
 # Name the output lightcurve
 OUTPUT_LIGHTCURVE_JDmag_NAME=`basename $INPUT_LIGHTCURVE .txt`_sorted_in_JD.txt
 # Convert the lightcurve to a pretier version of "JD mag" format and sort it (just for convenience of finding start and stop times)
 # and this is a silly trick to properly sort floating point numbers with 'sort'
 cat $INPUT_LIGHTCURVE | awk '{printf "%.6lf %7.4lf\n",$1*1000,$2}' | sort -n | awk '{printf "%.6lf %7.4lf\n",$1/1000,$2}' | awk '{printf "%14.6lf %7.4lf\n",$1+2400000.5,$2}' > "$RESULTS_DIR"/"$OUTPUT_LIGHTCURVE_JDmag_NAME"
 # Determine a period search range
 JD_MIN=`head -n1 "$RESULTS_DIR"/"$OUTPUT_LIGHTCURVE_JDmag_NAME" | awk '{print $1}'`
 JD_MAX=`tail -n1 "$RESULTS_DIR"/"$OUTPUT_LIGHTCURVE_JDmag_NAME" | awk '{print $1}'` 
 PMAX=`echo "
define abs(i) {
 if (i < 0) return (-i)
 return (i)
}
jd_range=abs(($JD_MAX)-($JD_MIN))
define max_period(jd_range) {
 if( jd_range > 1000 ) return (100)
 if( jd_range > 100 ) return (10)
 if( jd_range > 10 ) return (1)
 return (0.3)
}
max_period(jd_range)
"|bc -ql`
 if [ "$PMAX" = ".3" ];then
  PMIN=0.03
 else
  PMIN=0.1
 fi
 echo "$PMIN $PMAX"
 
 # Upload the converted lightcurve file to the server
 URL_OF_RESULTS_PAGE=`curl -F file=@"$RESULTS_DIR/$OUTPUT_LIGHTCURVE_JDmag_NAME" -F submit="Compute" -F pmax="$PMAX" -F pmin="$PMIN" -F phaseshift="0.1" -F fileupload="True" -F applyhelcor="No" -F timesys="UTC" -F position="00:00:00.00 +00:00:00.0" "http://scan.sai.msu.ru/cgi-bin/lk/process_lightcurve.py" --user vast48:khyzbaojMhztNkWd | grep Refresh | awk '{print $2}' FS='url=' | awk '{print $1}' FS='"'`

 # Print out the resultspage URL
 echo $URL_OF_RESULTS_PAGE
 # If you want to view it in a web browser, try something like
 # firefox $URL_OF_RESULTS_PAGE
 
 
 
 ##### Download the results page with wget to view it later
 
 # Go to the temporary dir
 if [ ! -d "$TMP_DIR_FOR_HTML_PNG" ];then
  mkdir "$TMP_DIR_FOR_HTML_PNG"
 fi
 cd "$TMP_DIR_FOR_HTML_PNG"
 
 # Get the results page
 wget -c --no-parent -nd --convert-links -A".css,.html,.png" -p "$URL_OF_RESULTS_PAGE"
 
 # Go back to the main dir
 cd "$SCRIPT_WORKDIR"
 
 # Rename the results directory
 mv "$TMP_DIR_FOR_HTML_PNG" "$RESULTS_DIR"/`basename "$OUTPUT_LIGHTCURVE_JDmag_NAME" _sorted_in_JD.txt`
 
 # !!! Uncomment this if you want to try just the first star !!!
 #exit 
 
done
